.. _utilities.misc:

Several utility functions are used throughout sisl.

Range routines
==============

.. currentmodule:: sisl.utils

.. autosummary::
   :toctree: generated/

   strmap
   strseq
   lstranges
   erange
   list2str
   fileindex


Miscellaneous routines
======================

.. autosummary::
   :toctree: generated/

   str_spec
   direction - abc/012 -> 012
   listify
   angle - radian to degree
   iter_shape
   math_eval
   batched_indices
